weaviate.collections.aggregations package
=========================================

.. automodule:: weaviate.collections.aggregations
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

weaviate.collections.aggregations.base module
---------------------------------------------

.. automodule:: weaviate.collections.aggregations.base
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.aggregations.near\_image module
----------------------------------------------------

.. automodule:: weaviate.collections.aggregations.near_image
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.aggregations.near\_object module
-----------------------------------------------------

.. automodule:: weaviate.collections.aggregations.near_object
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.aggregations.near\_text module
---------------------------------------------------

.. automodule:: weaviate.collections.aggregations.near_text
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.aggregations.near\_vector module
-----------------------------------------------------

.. automodule:: weaviate.collections.aggregations.near_vector
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.aggregations.over\_all module
--------------------------------------------------

.. automodule:: weaviate.collections.aggregations.over_all
   :members:
   :undoc-members:
   :show-inheritance:
